Rename connection_id to server_connection_id
This is a step on the way to enabling client connection IDs. It will make the code less ambiguous once we introduce client_connection_id.
gfe-relnote: n/a, renaming code only
PiperOrigin-RevId: 249045070
Change-Id: Ia7ba75511f96c896bc6f0f4978dae2cd13e707fb
diff --git a/quic/core/quic_packet_creator.h b/quic/core/quic_packet_creator.h
index 6e1f7a2..259b577 100644
--- a/quic/core/quic_packet_creator.h
+++ b/quic/core/quic_packet_creator.h
@@ -56,10 +56,10 @@
virtual void OnFrameAddedToPacket(const QuicFrame& frame) {}
};
- QuicPacketCreator(QuicConnectionId connection_id,
+ QuicPacketCreator(QuicConnectionId server_connection_id,
QuicFramer* framer,
DelegateInterface* delegate);
- QuicPacketCreator(QuicConnectionId connection_id,
+ QuicPacketCreator(QuicConnectionId server_connection_id,
QuicFramer* framer,
QuicRandom* random,
DelegateInterface* delegate);
@@ -222,11 +222,12 @@
// Returns length of source connection ID to send over the wire.
QuicConnectionIdLength GetSourceConnectionIdLength() const;
- // Sets whether the connection ID should be sent over the wire.
- void SetConnectionIdIncluded(QuicConnectionIdIncluded connection_id_included);
+ // Sets whether the server connection ID should be sent over the wire.
+ void SetServerConnectionIdIncluded(
+ QuicConnectionIdIncluded server_connection_id_included);
// Update the connection ID used in outgoing packets.
- void SetConnectionId(QuicConnectionId connection_id);
+ void SetServerConnectionId(QuicConnectionId server_connection_id);
// Sets the encryption level that will be applied to new packets.
void set_encryption_level(EncryptionLevel level) {
@@ -393,8 +394,8 @@
// Maximum length including headers and encryption (UDP payload length.)
QuicByteCount max_packet_length_;
size_t max_plaintext_size_;
- // Whether the connection_id is sent over the wire.
- QuicConnectionIdIncluded connection_id_included_;
+ // Whether the server_connection_id is sent over the wire.
+ QuicConnectionIdIncluded server_connection_id_included_;
// Frames to be added to the next SerializedPacket
QuicFrames queued_frames_;
@@ -403,7 +404,7 @@
// TODO(ianswett): Move packet_size_ into SerializedPacket once
// QuicEncryptedPacket has been flattened into SerializedPacket.
size_t packet_size_;
- QuicConnectionId connection_id_;
+ QuicConnectionId server_connection_id_;
// Packet used to invoke OnSerializedPacket.
SerializedPacket packet_;